@@ -1,17 +1,4 @@
 #ABSTRACT: 爱尚小说的解析模块 http://www.23hh.com
-=pod
-
-=encoding utf8
-
-=head1 FUNCTION
-
-=head2 parse_index
-
-=head2 parse_chapter
-
-=head2 parse_writer
-
-=cut
 package Novel::Robot::Parser::Asxs;
 use strict;
 use warnings;
@@ -46,7 +33,9 @@ sub parse_index {
     $ref->{writer}=~s/作者：//;
     $ref->{book}=~s/\s*最新章节\s*$//;
 
-    $ref->{chapter_info} = [ grep { exists $_->{url} } @{ $ref->{chapter_info} } ];
+    $ref->{chapter_info} = [
+        grep { $_->{url} } @{ $ref->{chapter_info} }
+    ];
 
     return $ref;
 } ## end sub parse_index
